@@ -9,6 +9,7 @@ namespace dplyr {
         virtual ~GroupedSubset(){} ;
         virtual SEXP get( const SlicingIndex& indices ) = 0 ;
         virtual SEXP get_variable() const = 0 ;
+        virtual bool is_summary() const = 0; 
     } ;
     
     template <int RTYPE>
@@ -25,6 +26,9 @@ namespace dplyr {
         virtual SEXP get_variable() const {
             return object ;    
         }
+        virtual bool is_summary() const {
+            return false;    
+        }
         
     private:
         SEXP object ;
@@ -59,6 +63,9 @@ namespace dplyr {
         virtual SEXP get_variable() const {
             return object ;    
         }
+        virtual bool is_summary() const {
+            return true;    
+        }
         
     private:
         Rcpp::Vector<RTYPE> object ;
