@@ -297,7 +297,11 @@ test_that("mutate works on zero-row grouped data frame (#596)", {
 })
 
 test_that("Non-ascii column names in version 0.3 are not duplicated (#636)", {
-  res <- data_frame(a = "1", å = "2") %>% mutate_each(funs(as.numeric)) %>% names
+  df  <- data_frame(a = "1", b = "2")
+  names(df) <- c("a", "å")
+  Encoding(names(df)) <- "unknown"
+  
+  res <- df %>% mutate_each(funs(as.numeric)) %>% names
   expect_equal(res, c("a", "å") )
 })
 
